@@ -5,7 +5,7 @@ __license__ = "Apache-2.0"
 from typing import Iterable
 
 from . import request
-from .base import BaseClient, CallbackFnType, InputFnType
+from .base import BaseClient, CallbackFnType, InputType
 from .helper import callback_exec
 from .request import GeneratorSourceType
 from .websocket import WebSocketClientMixin
@@ -28,96 +28,146 @@ class Client(BaseClient):
         if self.args.return_results:
             return result
 
-    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
-    def train(self, input_fn: InputFnType,
-              on_done: CallbackFnType = None,
-              on_error: CallbackFnType = None,
-              on_always: CallbackFnType = None,
-              **kwargs) -> None:
+    @deprecated_alias(
+        input_fn=('inputs', 0),
+        buffer=('inputs', 1),
+        callback=('on_done', 1),
+        output_fn=('on_done', 1),
+    )
+    def train(
+        self,
+        inputs: InputType,
+        on_done: CallbackFnType = None,
+        on_error: CallbackFnType = None,
+        on_always: CallbackFnType = None,
+        **kwargs
+    ) -> None:
         """Issue 'train' request to the Flow.
 
-        :param input_fn: the input function that generates the content
+        :param inputs: input data which can be an Iterable, a function which returns an Iterable, or a single Document
         :param on_done: the function to be called when the :class:`Request` object is resolved.
         :param on_error: the function to be called when the :class:`Request` object is rejected.
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
-        :param kwargs:
-        :return:
+        :param kwargs: additional parameters
+        :return: None
         """
         self.mode = RequestType.TRAIN
-        return run_async(self._get_results, input_fn, on_done, on_error, on_always, **kwargs)
+        return run_async(
+            self._get_results, inputs, on_done, on_error, on_always, **kwargs
+        )
 
-    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
-    def search(self, input_fn: InputFnType,
-               on_done: CallbackFnType = None,
-               on_error: CallbackFnType = None,
-               on_always: CallbackFnType = None,
-               **kwargs) -> None:
+    @deprecated_alias(
+        input_fn=('inputs', 0),
+        buffer=('inputs', 1),
+        callback=('on_done', 1),
+        output_fn=('on_done', 1),
+    )
+    def search(
+        self,
+        inputs: InputType,
+        on_done: CallbackFnType = None,
+        on_error: CallbackFnType = None,
+        on_always: CallbackFnType = None,
+        **kwargs
+    ) -> None:
         """Issue 'search' request to the Flow.
 
-        :param input_fn: the input function that generates the content
+        :param inputs: input data which can be an Iterable, a function which returns an Iterable, or a single Document
         :param on_done: the function to be called when the :class:`Request` object is resolved.
         :param on_error: the function to be called when the :class:`Request` object is rejected.
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
-        :param kwargs:
-        :return:
+        :param kwargs: additional parameters
+        :return: None
         """
         self.mode = RequestType.SEARCH
         self.add_default_kwargs(kwargs)
-        return run_async(self._get_results, input_fn, on_done, on_error, on_always, **kwargs)
+        return run_async(
+            self._get_results, inputs, on_done, on_error, on_always, **kwargs
+        )
 
-    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
-    def index(self, input_fn: InputFnType,
-              on_done: CallbackFnType = None,
-              on_error: CallbackFnType = None,
-              on_always: CallbackFnType = None,
-              **kwargs) -> None:
+    @deprecated_alias(
+        input_fn=('inputs', 0),
+        buffer=('inputs', 1),
+        callback=('on_done', 1),
+        output_fn=('on_done', 1),
+    )
+    def index(
+        self,
+        inputs: InputType,
+        on_done: CallbackFnType = None,
+        on_error: CallbackFnType = None,
+        on_always: CallbackFnType = None,
+        **kwargs
+    ) -> None:
         """Issue 'index' request to the Flow.
 
-        :param input_fn: the input function that generates the content
+        :param inputs: input data which can be an Iterable, a function which returns an Iterable, or a single Document
         :param on_done: the function to be called when the :class:`Request` object is resolved.
         :param on_error: the function to be called when the :class:`Request` object is rejected.
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
-        :param kwargs:
-        :return:
+        :param kwargs: additional parameters
+        :return: None
         """
         self.mode = RequestType.INDEX
-        return run_async(self._get_results, input_fn, on_done, on_error, on_always, **kwargs)
+        return run_async(
+            self._get_results, inputs, on_done, on_error, on_always, **kwargs
+        )
 
-    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
-    def update(self, input_fn: InputFnType,
-               on_done: CallbackFnType = None,
-               on_error: CallbackFnType = None,
-               on_always: CallbackFnType = None,
-               **kwargs) -> None:
+    @deprecated_alias(
+        input_fn=('inputs', 0),
+        buffer=('inputs', 1),
+        callback=('on_done', 1),
+        output_fn=('on_done', 1),
+    )
+    def update(
+        self,
+        inputs: InputType,
+        on_done: CallbackFnType = None,
+        on_error: CallbackFnType = None,
+        on_always: CallbackFnType = None,
+        **kwargs
+    ) -> None:
         """Issue 'update' request to the Flow.
 
-        :param input_fn: the input function that generates the content
+        :param inputs: input data which can be an Iterable, a function which returns an Iterable, or a single Document
         :param on_done: the function to be called when the :class:`Request` object is resolved.
         :param on_error: the function to be called when the :class:`Request` object is rejected.
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
-        :param kwargs:
-        :return:
+        :param kwargs: additional parameters
+        :return: None
         """
         self.mode = RequestType.UPDATE
-        return run_async(self._get_results, input_fn, on_done, on_error, on_always, **kwargs)
+        return run_async(
+            self._get_results, inputs, on_done, on_error, on_always, **kwargs
+        )
 
-    @deprecated_alias(buffer=('input_fn', 1), callback=('on_done', 1), output_fn=('on_done', 1))
-    def delete(self, input_fn: Iterable[str],
-               on_done: CallbackFnType = None,
-               on_error: CallbackFnType = None,
-               on_always: CallbackFnType = None,
-               **kwargs) -> None:
+    @deprecated_alias(
+        input_fn=('inputs', 0),
+        buffer=('inputs', 1),
+        callback=('on_done', 1),
+        output_fn=('on_done', 1),
+    )
+    def delete(
+        self,
+        inputs: Iterable[str],
+        on_done: CallbackFnType = None,
+        on_error: CallbackFnType = None,
+        on_always: CallbackFnType = None,
+        **kwargs
+    ) -> None:
         """Issue 'update' request to the Flow.
 
-        :param input_fn: the input function that generates the content
+        :param inputs: input data which can be an Iterable, a function which returns an Iterable, or a single Document
         :param on_done: the function to be called when the :class:`Request` object is resolved.
         :param on_error: the function to be called when the :class:`Request` object is rejected.
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
-        :param kwargs:
-        :return:
+        :param kwargs: additional parameters
+        :return: None
         """
         self.mode = RequestType.DELETE
-        return run_async(self._get_results, input_fn, on_done, on_error, on_always, **kwargs)
+        return run_async(
+            self._get_results, inputs, on_done, on_error, on_always, **kwargs
+        )
 
 
 class WebSocketClient(Client, WebSocketClientMixin):
