@@ -1,22 +1,55 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
-from typing import Dict
+from typing import Dict, Optional, Sequence
 
 import numpy as np
 
 from .. import BaseExecutor
 
+COL_STR_TYPE = 'U64'  #: the ID column data type for score matrix
+
 
 class BaseRanker(BaseExecutor):
     """The base class for a `Ranker`"""
 
+    def __init__(
+        self,
+        query_required_keys: Optional[Sequence[str]] = None,
+        match_required_keys: Optional[Sequence[str]] = None,
+        *args,
+        **kwargs
+    ):
+        """
+
+        :param query_required_keys: Set of keys or features to be extracted from query `Document` by the `Driver` so that
+            they are passed as query features or metainfo.
+        :param match_required_keys: Set of keys or features to be extracted from match `Document` by the `Driver` so that
+            they are passed as match features or metainfo.
+
+        .. note::
+            See how the attributes are accessed in :class:`Document` in :meth:`get_attrs`.
+
+            .. highlight:: python
+            .. code-block:: python
+
+                query = Document({'tags': {'color': 'blue'})
+                match = Document({'tags': {'color': 'blue', 'price': 1000}})
+
+                ranker = BaseRanker(query_required_keys=('tags__color'), match_required_keys=('tags__color, 'tags__price')
+        """
+
+        super().__init__(*args, **kwargs)
+        self.query_required_keys = query_required_keys
+        self.match_required_keys = match_required_keys
+
     def score(self, *args, **kwargs):
+        """Calculate the score. Base class method needs to be implemented in subclass."""
         raise NotImplementedError
 
 
 class Chunk2DocRanker(BaseRanker):
-    """ A :class:`Chunk2DocRanker` translates the chunk-wise score (distance) to the doc-wise score.
+    """A :class:`Chunk2DocRanker` translates the chunk-wise score (distance) to the doc-wise score.
 
     In the query-time, :class:`Chunk2DocRanker` is an almost-always required component.
     Because in the end we want to retrieve top-k documents of given query-document not top-k chunks of
@@ -30,13 +63,14 @@ class Chunk2DocRanker(BaseRanker):
 
     """
 
-    required_keys = {'text'}  #: a set of ``str``, key-values to extracted from the chunk-level protobuf message
-    COL_MATCH_PARENT_ID = 'match_parent_id'
-    COL_MATCH_ID = 'match_id'
-    COL_DOC_CHUNK_ID = 'doc_chunk_id'
+    COL_PARENT_ID = 'match_parent_id'
+    COL_DOC_CHUNK_ID = 'match_doc_chunk_id'
+    COL_QUERY_CHUNK_ID = 'match_query_chunk_id'
     COL_SCORE = 'score'
 
-    def score(self, match_idx: 'np.ndarray', query_chunk_meta: Dict, match_chunk_meta: Dict) -> 'np.ndarray':
+    def score(
+        self, match_idx: 'np.ndarray', query_chunk_meta: Dict, match_chunk_meta: Dict
+    ) -> 'np.ndarray':
         """
         Translate the chunk-level top-k results into doc-level top-k results. Some score functions may leverage the
         meta information of the query, hence the meta info of the query chunks and matched chunks are given
@@ -49,11 +83,11 @@ class Chunk2DocRanker(BaseRanker):
                 - ``match_idx[:, 3]``: distance/metric/score between the query and matched chunks, float
         :type match_idx: np.ndarray.
         :param query_chunk_meta: The meta information of the query chunks, where the key is query chunks' ``chunk_id``,
-            the value is extracted by the ``required_keys``.
+            the value is extracted by the ``query_required_keys``.
         :type query_chunk_meta: Dict.
         :param match_chunk_meta: The meta information of the matched chunks, where the key is matched chunks'
-            ``chunk_id``, the value is extracted by the ``required_keys``.
-        :type query_chunk_meta: Dict.
+            ``chunk_id``, the value is extracted by the ``match_required_keys``.
+        :type match_chunk_meta: Dict.
         :return: A [N x 2] numpy ``ndarray``, where the first column is the matched documents' ``doc_id`` (integer)
                 the second column is the score/distance/metric between the matched doc and the query doc (float).
         :rtype: np.ndarray.
@@ -61,7 +95,9 @@ class Chunk2DocRanker(BaseRanker):
         _groups = self.group_by_doc_id(match_idx)
         r = []
         for _g in _groups:
-            _doc_id, _doc_score = self._get_score(_g, query_chunk_meta, match_chunk_meta)
+            _doc_id, _doc_score = self._get_score(
+                _g, query_chunk_meta, match_chunk_meta
+            )
             r.append((_doc_id, _doc_score))
         return self.sort_doc_by_score(r)
 
@@ -71,7 +107,7 @@ class Chunk2DocRanker(BaseRanker):
         :return: an iterator over the groups.
         :rtype: :class:`Chunk2DocRanker`.
         """
-        return self._group_by(match_idx, self.COL_MATCH_PARENT_ID)
+        return self._group_by(match_idx, self.COL_PARENT_ID)
 
     @staticmethod
     def _group_by(match_idx, col_name):
@@ -81,7 +117,9 @@ class Chunk2DocRanker(BaseRanker):
         # group by ``col``
         return np.split(_sorted_m, np.cumsum(_doc_counts))[:-1]
 
-    def _get_score(self, match_idx, query_chunk_meta, match_chunk_meta, *args, **kwargs):
+    def _get_score(
+        self, match_idx, query_chunk_meta, match_chunk_meta, *args, **kwargs
+    ):
         raise NotImplementedError
 
     @staticmethod
@@ -93,15 +131,18 @@ class Chunk2DocRanker(BaseRanker):
         :return: A `np.ndarray` in the shape of [N x 2], where `N` in the length of the input list.
         :rtype: np.ndarray
         """
-        r = np.array(r, dtype=[
-            (Chunk2DocRanker.COL_MATCH_PARENT_ID, np.object),
-            (Chunk2DocRanker.COL_SCORE, np.float64)]
-                     )
+        r = np.array(
+            r,
+            dtype=[
+                (Chunk2DocRanker.COL_PARENT_ID, COL_STR_TYPE),
+                (Chunk2DocRanker.COL_SCORE, np.float64),
+            ],
+        )
         return np.sort(r, order=Chunk2DocRanker.COL_SCORE)[::-1]
 
     def get_doc_id(self, match_with_same_doc_id):
         """Return document id that matches with given id :param:`match_with_same_doc_id`"""
-        return match_with_same_doc_id[0][self.COL_MATCH_PARENT_ID]
+        return match_with_same_doc_id[0][self.COL_PARENT_ID]
 
 
 class Match2DocRanker(BaseRanker):
@@ -115,10 +156,12 @@ class Match2DocRanker(BaseRanker):
         - BucketShuffleRanker (first buckets matches and then sort each bucket).
     """
 
-    COL_MATCH_ID = 'match_id'
+    COL_MATCH_ID = 'match_doc_chunk_id'
     COL_SCORE = 'score'
 
-    def score(self, query_meta: Dict, old_match_scores: Dict, match_meta: Dict) -> 'np.ndarray':
+    def score(
+        self, query_meta: Dict, old_match_scores: Dict, match_meta: Dict
+    ) -> 'np.ndarray':
         """
         Calculates the new scores for matches and returns them.
 
