@@ -10,6 +10,7 @@ from jina.proto.jina_pb2 import DocumentProto, QueryLangProto
 
 class JinaStatusModel(BaseModel):
     """Pydantic BaseModel for Jina status, used as the response model in REST app."""
+
     jina: Dict
     envs: Dict
     used_memory: str
@@ -27,7 +28,10 @@ def build_model_from_pb(name: str, pb_model: Callable):
 
     dp = MessageToDict(pb_model(), including_default_value_fields=True)
 
-    all_fields = {k: (name if k in ('chunks', 'matches') else type(v), Field(default=v)) for k, v in dp.items()}
+    all_fields = {
+        k: (name if k in ('chunks', 'matches') else type(v), Field(default=v))
+        for k, v in dp.items()
+    }
     if pb_model == QueryLangProto:
         all_fields['parameters'] = (Dict, Field(default={}))
 
@@ -46,9 +50,11 @@ class JinaRequestModel(BaseModel):
 
     The base model for Jina REST request.
     """
+
     # To avoid an error while loading the request model schema on swagger, we've added an example.
-    data: Union[List[JinaDocumentModel], List[Dict[str, Any]], List[str], List[bytes]] = \
-        Field(..., example=[Document().dict()])
+    data: Union[
+        List[JinaDocumentModel], List[Dict[str, Any]], List[str], List[bytes]
+    ] = Field(..., example=[Document().dict()])
     request_size: Optional[int] = default_request_size
     mime_type: Optional[str] = ''
     queryset: Optional[List[JinaQueryLangModel]] = None
@@ -57,29 +63,35 @@ class JinaRequestModel(BaseModel):
 
 class JinaIndexRequestModel(JinaRequestModel):
     """Index request model."""
+
     pass
 
 
 class JinaSearchRequestModel(JinaRequestModel):
     """Search request model."""
+
     pass
 
 
 class JinaUpdateRequestModel(JinaRequestModel):
     """Update request model."""
+
     pass
 
 
 class JinaDeleteRequestModel(JinaRequestModel):
     """Delete request model."""
+
     data: List[str]
 
 
 class JinaControlRequestModel(JinaRequestModel):
     """Control request model."""
+
     pass
 
 
 class JinaTrainRequestModel(JinaRequestModel):
     """Train request model."""
+
     pass
