@@ -7,35 +7,43 @@ import urllib.parse
 import urllib.request
 import warnings
 from hashlib import blake2b
-from typing import Union, Dict, Optional, TypeVar, Any, Callable, Sequence, Tuple
+from typing import Union, Dict, Optional, TypeVar, Any, Tuple
 
 import numpy as np
 from google.protobuf import json_format
 from google.protobuf.field_mask_pb2 import FieldMask
 
+from .traversable import Traversable
 from .converters import png_to_buffer, to_datauri, guess_mime, to_image_blob
 from ..mixin import ProtoTypeMixin
 from ..ndarray.generic import NdArray
+from ..querylang.queryset.dunderkey import dunder_get
 from ..score import NamedScore
 from ..sets.chunk import ChunkSet
 from ..sets.match import MatchSet
 from ...excepts import BadDocType
 from ...helper import is_url, typename, random_identity, download_mermaid_url
 from ...importer import ImportExtensions
+from ...logging import default_logger
 from ...proto import jina_pb2
 
 __all__ = ['Document', 'DocumentContentType', 'DocumentSourceType']
 DIGEST_SIZE = 8
 
 DocumentContentType = TypeVar('DocumentContentType', bytes, str, np.ndarray)
-DocumentSourceType = TypeVar('DocumentSourceType',
-                             jina_pb2.DocumentProto, bytes, str, Dict)
+DocumentSourceType = TypeVar(
+    'DocumentSourceType', jina_pb2.DocumentProto, bytes, str, Dict
+)
 
-_document_fields = set(list(jina_pb2.DocumentProto().DESCRIPTOR.fields_by_camelcase_name) + list(
-    jina_pb2.DocumentProto().DESCRIPTOR.fields_by_name))
+_document_fields = set(
+    list(jina_pb2.DocumentProto().DESCRIPTOR.fields_by_camelcase_name)
+    + list(jina_pb2.DocumentProto().DESCRIPTOR.fields_by_name)
+)
+
+_all_mime_types = set(mimetypes.types_map.values())
 
 
-class Document(ProtoTypeMixin):
+class Document(ProtoTypeMixin, Traversable):
     """
     :class:`Document` is one of the **primitive data type** in Jina.
 
@@ -97,11 +105,14 @@ class Document(ProtoTypeMixin):
 
     """
 
-    def __init__(self, document: Optional[DocumentSourceType] = None,
-                 field_resolver: Dict[str, str] = None,
-                 copy: bool = False, **kwargs):
+    def __init__(
+        self,
+        document: Optional[DocumentSourceType] = None,
+        field_resolver: Dict[str, str] = None,
+        copy: bool = False,
+        **kwargs,
+    ):
         """
-
         :param document: the document to construct from. If ``bytes`` is given
                 then deserialize a :class:`DocumentProto`; ``dict`` is given then
                 parse a :class:`DocumentProto` from it; ``str`` is given, then consider
@@ -141,7 +152,9 @@ class Document(ProtoTypeMixin):
                     document = json.loads(document)
 
                 if field_resolver:
-                    document = {field_resolver.get(k, k): v for k, v in document.items()}
+                    document = {
+                        field_resolver.get(k, k): v for k, v in document.items()
+                    }
 
                 user_fields = set(document.keys())
                 if _document_fields.issuperset(user_fields):
@@ -150,7 +163,9 @@ class Document(ProtoTypeMixin):
                     _intersect = _document_fields.intersection(user_fields)
                     _remainder = user_fields.difference(_intersect)
                     if _intersect:
-                        json_format.ParseDict({k: document[k] for k in _intersect}, self._pb_body)
+                        json_format.ParseDict(
+                            {k: document[k] for k in _intersect}, self._pb_body
+                        )
                     if _remainder:
                         self._pb_body.tags.update({k: document[k] for k in _remainder})
             elif isinstance(document, bytes):
@@ -159,13 +174,15 @@ class Document(ProtoTypeMixin):
                 # the context manager below converts this warning into exception and throw it
                 # properly
                 with warnings.catch_warnings():
-                    warnings.filterwarnings('error',
-                                            'Unexpected end-group tag',
-                                            category=RuntimeWarning)
+                    warnings.filterwarnings(
+                        'error', 'Unexpected end-group tag', category=RuntimeWarning
+                    )
                     try:
                         self._pb_body.ParseFromString(document)
                     except RuntimeWarning as ex:
-                        raise BadDocType(f'fail to construct a document from {document}') from ex
+                        raise BadDocType(
+                            f'fail to construct a document from {document}'
+                        ) from ex
             elif isinstance(document, Document):
                 if copy:
                     self._pb_body.CopyFrom(document.proto)
@@ -175,9 +192,11 @@ class Document(ProtoTypeMixin):
                 # note ``None`` is not considered as a bad type
                 raise ValueError(f'{typename(document)} is not recognizable')
         except Exception as ex:
-            raise BadDocType(f'fail to construct a document from {document}, '
-                             f'if you are trying to set the content '
-                             f'you may use "Document(content=your_content)"') from ex
+            raise BadDocType(
+                f'fail to construct a document from {document}, '
+                f'if you are trying to set the content '
+                f'you may use "Document(content=your_content)"'
+            ) from ex
 
         if self._pb_body.id is None or not self._pb_body.id:
             self.id = random_identity(use_uuid1=True)
@@ -187,27 +206,33 @@ class Document(ProtoTypeMixin):
 
     @property
     def length(self) -> int:
-        """Get the length of of the document."""
+        """
+        The number of siblings of the :class:``Document``
+
+        .. # noqa: DAR201
+        :getter: number of siblings
+        :setter: number of siblings
+        :type: int
+        """
         # TODO(Han): rename this to siblings as this shadows the built-in `length`
+
         return self._pb_body.length
 
     @length.setter
     def length(self, value: int):
-        """
-        Set the length of of the document.
-
-        :param value: The int length of the document
-        """
         self._pb_body.length = value
 
     @property
     def weight(self) -> float:
-        """Return the weight of the document."""
+        """
+        :return: the weight of the document
+        """
         return self._pb_body.weight
 
     @weight.setter
     def weight(self, value: float):
-        """Set the weight of the document.
+        """
+        Set the weight of the document.
 
         :param value: the float weight of the document.
         """
@@ -215,7 +240,8 @@ class Document(ProtoTypeMixin):
 
     @property
     def modality(self) -> str:
-        """Get the modality of the document."""
+        """
+        :return: the modality of the document."""
         return self._pb_body.modality
 
     @modality.setter
@@ -229,12 +255,14 @@ class Document(ProtoTypeMixin):
         return self._pb_body.content_hash
 
     @staticmethod
-    def _update(source: 'Document',
-                destination: 'Document',
-                exclude_fields: Optional[Tuple[str]] = None,
-                include_fields: Optional[Tuple[str]] = None,
-                replace_message_field: bool = True,
-                replace_repeated_field: bool = True) -> None:
+    def _update(
+        source: 'Document',
+        destination: 'Document',
+        exclude_fields: Optional[Tuple[str]] = None,
+        include_fields: Optional[Tuple[str]] = None,
+        replace_message_field: bool = True,
+        replace_repeated_field: bool = True,
+    ) -> None:
         """Merge fields specified in ``include_fields`` or ``exclude_fields`` from source to destination.
 
         :param source: source :class:`Document` object.
@@ -256,38 +284,53 @@ class Document(ProtoTypeMixin):
             # same behavior as copy
             destination.CopyFrom(source)
         elif include_fields is not None and exclude_fields is None:
-            FieldMask(paths=include_fields).MergeMessage(source.proto, destination.proto,
-                                                         replace_message_field=replace_message_field,
-                                                         replace_repeated_field=replace_repeated_field)
+            FieldMask(paths=include_fields).MergeMessage(
+                source.proto,
+                destination.proto,
+                replace_message_field=replace_message_field,
+                replace_repeated_field=replace_repeated_field,
+            )
         elif exclude_fields is not None:
             empty_doc = jina_pb2.DocumentProto()
 
             _dest = jina_pb2.DocumentProto()
             # backup exclude fields in destination
-            FieldMask(paths=exclude_fields).MergeMessage(destination.proto, _dest,
-                                                         replace_repeated_field=True,
-                                                         replace_message_field=True)
+            FieldMask(paths=exclude_fields).MergeMessage(
+                destination.proto,
+                _dest,
+                replace_repeated_field=True,
+                replace_message_field=True,
+            )
 
             if include_fields is None:
                 # override dest with src
                 destination.CopyFrom(source)
             else:
                 # only update include fields
-                FieldMask(paths=include_fields).MergeMessage(source.proto, destination.proto,
-                                                             replace_message_field=replace_message_field,
-                                                             replace_repeated_field=replace_repeated_field)
+                FieldMask(paths=include_fields).MergeMessage(
+                    source.proto,
+                    destination.proto,
+                    replace_message_field=replace_message_field,
+                    replace_repeated_field=replace_repeated_field,
+                )
 
             # clear the exclude fields
-            FieldMask(paths=exclude_fields).MergeMessage(empty_doc, destination.proto,
-                                                         replace_repeated_field=True,
-                                                         replace_message_field=True)
+            FieldMask(paths=exclude_fields).MergeMessage(
+                empty_doc,
+                destination.proto,
+                replace_repeated_field=True,
+                replace_message_field=True,
+            )
 
             # recover exclude fields
             destination.proto.MergeFrom(_dest)
 
-    def update(self, source: 'Document',
-               exclude_fields: Optional[Tuple[str, ...]] = None,
-               include_fields: Optional[Tuple[str, ...]] = None) -> None:
+    def update(
+        self,
+        source: 'Document',
+        exclude_fields: Optional[Tuple[str, ...]] = None,
+        include_fields: Optional[Tuple[str, ...]] = None,
+    ) -> None:
         """Updates fields specified in ``include_fields`` from the source to current Document.
 
         :param source: source :class:`Document` object.
@@ -299,30 +342,45 @@ class Document(ProtoTypeMixin):
             *. ``destination`` will be modified in place, ``source`` will be unchanged
         """
         if (include_fields and not isinstance(include_fields, tuple)) or (
-                exclude_fields and not isinstance(exclude_fields, tuple)):
+            exclude_fields and not isinstance(exclude_fields, tuple)
+        ):
             raise TypeError('include_fields and exclude_fields must be tuple of str')
 
         if exclude_fields is None:
             if include_fields:
-                exclude_fields = tuple(f for f in self.non_empty_fields if f not in include_fields)
+                exclude_fields = tuple(
+                    f for f in self.non_empty_fields if f not in include_fields
+                )
             else:
                 exclude_fields = self.non_empty_fields
 
         if include_fields and exclude_fields:
             _intersect = set(include_fields).intersection(exclude_fields)
             if _intersect:
-                raise ValueError(f'{_intersect} is in both `include_fields` and `exclude_fields`')
+                raise ValueError(
+                    f'{_intersect} is in both `include_fields` and `exclude_fields`'
+                )
 
-        self._update(source, self,
-                     exclude_fields=exclude_fields,
-                     include_fields=include_fields,
-                     replace_message_field=True,
-                     replace_repeated_field=True)
+        self._update(
+            source,
+            self,
+            exclude_fields=exclude_fields,
+            include_fields=include_fields,
+            replace_message_field=True,
+            replace_repeated_field=True,
+        )
 
-    def update_content_hash(self,
-                            exclude_fields: Optional[Tuple[str]] = (
-                                    'id', 'chunks', 'matches', 'content_hash', 'parent_id'),
-                            include_fields: Optional[Tuple[str]] = None) -> None:
+    def update_content_hash(
+        self,
+        exclude_fields: Optional[Tuple[str]] = (
+            'id',
+            'chunks',
+            'matches',
+            'content_hash',
+            'parent_id',
+        ),
+        include_fields: Optional[Tuple[str]] = None,
+    ) -> None:
         """Update the document hash according to its content.
 
         :param exclude_fields: a tuple of field names that excluded when computing content hash
@@ -335,15 +393,21 @@ class Document(ProtoTypeMixin):
         masked_d.CopyFrom(self._pb_body)
         empty_doc = jina_pb2.DocumentProto()
         if include_fields and exclude_fields:
-            raise ValueError('"exclude_fields" and "exclude_fields" are mutually exclusive, use one only')
+            raise ValueError(
+                '"exclude_fields" and "exclude_fields" are mutually exclusive, use one only'
+            )
 
         if include_fields is not None:
             FieldMask(paths=include_fields).MergeMessage(masked_d, empty_doc)
             masked_d = empty_doc
         elif exclude_fields is not None:
-            FieldMask(paths=exclude_fields).MergeMessage(empty_doc, masked_d, replace_repeated_field=True)
+            FieldMask(paths=exclude_fields).MergeMessage(
+                empty_doc, masked_d, replace_repeated_field=True
+            )
 
-        self._pb_body.content_hash = blake2b(masked_d.SerializeToString(), digest_size=DIGEST_SIZE).hexdigest()
+        self._pb_body.content_hash = blake2b(
+            masked_d.SerializeToString(), digest_size=DIGEST_SIZE
+        ).hexdigest()
 
     @property
     def id(self) -> str:
@@ -442,7 +506,11 @@ class Document(ProtoTypeMixin):
                 self._pb_body.ClearField(k)
                 getattr(self._pb_body, k).update(v)
             else:
-                if hasattr(Document, k) and isinstance(getattr(Document, k), property) and getattr(Document, k).fset:
+                if (
+                    hasattr(Document, k)
+                    and isinstance(getattr(Document, k), property)
+                    and getattr(Document, k).fset
+                ):
                     # if class property has a setter
                     setattr(self, k, v)
                 elif hasattr(self._pb_body, k):
@@ -457,8 +525,45 @@ class Document(ProtoTypeMixin):
         .. seealso::
             :meth:`update` for bulk set/update attributes
 
+        .. note::
+            Arguments will be extracted using `dunder_get`
+            .. highlight:: python
+            .. code-block:: python
+
+                d = Document({'id': '123', 'hello': 'world', 'tags': {'id': 'external_id', 'good': 'bye'}})
+
+                assert d.id == '123'  # true
+                assert d.tags['hello'] == 'world' # true
+                assert d.tags['good'] == 'bye' # true
+                assert d.tags['id'] == 'external_id' # true
+
+                res = d.get_attrs(*['id', 'tags__hello', 'tags__good', 'tags__id'])
+
+                assert res['id'] == '123' # true
+                assert res['tags__hello'] == 'world' # true
+                assert res['tags__good'] == 'bye' # true
+                assert res['tags__id'] == 'external_id' # true
         """
-        return {k: getattr(self, k) for k in args if hasattr(self, k)}
+
+        ret = {}
+        for k in args:
+
+            try:
+                if hasattr(self, k):
+                    value = getattr(self, k)
+                else:
+                    value = dunder_get(self._pb_body, k)
+
+                if value is None:
+                    raise ValueError
+
+                ret[k] = value
+            except (AttributeError, ValueError):
+                default_logger.warning(
+                    f'Could not get attribute `{typename(self)}.{k}`, returning `None`'
+                )
+                ret[k] = None
+        return ret
 
     @property
     def buffer(self) -> bytes:
@@ -473,13 +578,16 @@ class Document(ProtoTypeMixin):
     def buffer(self, value: bytes):
         """Set the ``buffer`` to :param:`value`."""
         self._pb_body.buffer = value
-        if value:
-            with ImportExtensions(required=False,
-                                  pkg_name='python-magic',
-                                  help_text=f'can not sniff the MIME type '
-                                            f'MIME sniffing requires brew install '
-                                            f'libmagic (Mac)/ apt-get install libmagic1 (Linux)'):
+        if value and not self._pb_body.mime_type:
+            with ImportExtensions(
+                required=False,
+                pkg_name='python-magic',
+                help_text=f'can not sniff the MIME type '
+                f'MIME sniffing requires brew install '
+                f'libmagic (Mac)/ apt-get install libmagic1 (Linux)',
+            ):
                 import magic
+
                 self._pb_body.mime_type = magic.from_buffer(value, mime=True)
 
     @property
@@ -513,10 +621,12 @@ class Document(ProtoTypeMixin):
         :return:
         """
         scheme = urllib.parse.urlparse(value).scheme
-        if ((scheme in {'http', 'https'} and is_url(value))
-                or (scheme in {'data'})
-                or os.path.exists(value)
-                or os.access(os.path.dirname(value), os.W_OK)):
+        if (
+            (scheme in {'http', 'https'} and is_url(value))
+            or (scheme in {'data'})
+            or os.path.exists(value)
+            or os.access(os.path.dirname(value), os.W_OK)
+        ):
             self._pb_body.uri = value
             self.mime_type = guess_mime(value)
         else:
@@ -534,7 +644,7 @@ class Document(ProtoTypeMixin):
         :param value: the acceptable MIME type, raise ``ValueError`` when MIME type is not
                 recognizable.
         """
-        if value in mimetypes.types_map.values():
+        if value in _all_mime_types:
             self._pb_body.mime_type = value
         elif value:
             # given but not recognizable, do best guess
@@ -601,6 +711,16 @@ class Document(ProtoTypeMixin):
         """Set the granularity of the document."""
         self._pb_body.granularity = granularity_value
 
+    @property
+    def adjacency(self):
+        """Return the adjacency of the document."""
+        return self._pb_body.adjacency
+
+    @adjacency.setter
+    def adjacency(self, adjacency_value: int):
+        """Set the adjacency of the document."""
+        self._pb_body.adjacency = adjacency_value
+
     @property
     def score(self):
         """Return the score of the document."""
@@ -628,25 +748,42 @@ class Document(ProtoTypeMixin):
         self.blob = np.frombuffer(self.buffer)
 
     def convert_buffer_image_to_blob(self, color_axis: int = -1, **kwargs):
-        """ Convert an image buffer to blob
+        """Convert an image buffer to blob
 
         :param color_axis: the axis id of the color channel, ``-1`` indicates the color channel info at the last axis
         :param kwargs: reserved for maximum compatibility when using with ConvertDriver
         """
         self.blob = to_image_blob(io.BytesIO(self.buffer), color_axis)
 
-    def convert_blob_to_uri(self, width: int, height: int, resize_method: str = 'BILINEAR', **kwargs):
+    def convert_blob_to_uri(
+        self, width: int, height: int, resize_method: str = 'BILINEAR', **kwargs
+    ):
         """Assuming :attr:`blob` is a _valid_ image, set :attr:`uri` accordingly"""
         png_bytes = png_to_buffer(self.blob, width, height, resize_method)
         self.uri = 'data:image/png;base64,' + base64.b64encode(png_bytes).decode()
 
-    def convert_uri_to_blob(self, color_axis: int = -1, uri_prefix: str = None, **kwargs):
-        """ Convert uri to blob
+    def convert_uri_to_blob(
+        self, color_axis: int = -1, uri_prefix: str = None, **kwargs
+    ):
+        """Convert uri to blob
 
         :param color_axis: the axis id of the color channel, ``-1`` indicates the color channel info at the last axis
         :param kwargs: reserved for maximum compatibility when using with ConvertDriver
         """
-        self.blob = to_image_blob((uri_prefix + self.uri) if uri_prefix else self.uri, color_axis)
+        self.blob = to_image_blob(
+            (uri_prefix + self.uri) if uri_prefix else self.uri, color_axis
+        )
+
+    def convert_data_uri_to_blob(self, color_axis: int = -1, **kwargs):
+        """Convert data URI to image blob
+
+        :param color_axis: the axis id of the color channel, ``-1`` indicates the color channel info at the last axis
+        :param kwargs: reserved for maximum compatibility when using with ConvertDriver
+        """
+        req = urllib.request.Request(self.uri, headers={'User-Agent': 'Mozilla/5.0'})
+        with urllib.request.urlopen(req) as fp:
+            buffer = fp.read()
+        self.blob = to_image_blob(io.BytesIO(buffer), color_axis)
 
     def convert_uri_to_buffer(self, **kwargs):
         """Convert uri to buffer
@@ -656,7 +793,9 @@ class Document(ProtoTypeMixin):
 
         """
         if urllib.parse.urlparse(self.uri).scheme in {'http', 'https', 'data'}:
-            req = urllib.request.Request(self.uri, headers={'User-Agent': 'Mozilla/5.0'})
+            req = urllib.request.Request(
+                self.uri, headers={'User-Agent': 'Mozilla/5.0'}
+            )
             with urllib.request.urlopen(req) as fp:
                 self.buffer = fp.read()
         elif os.path.exists(self.uri):
@@ -665,8 +804,10 @@ class Document(ProtoTypeMixin):
         else:
             raise FileNotFoundError(f'{self.uri} is not a URL or a valid local path')
 
-    def convert_uri_to_data_uri(self, charset: str = 'utf-8', base64: bool = False, **kwargs):
-        """ Convert uri to data uri.
+    def convert_uri_to_data_uri(
+        self, charset: str = 'utf-8', base64: bool = False, **kwargs
+    ):
+        """Convert uri to data uri.
         Internally it reads uri into buffer and convert it to data uri
 
         :param charset: charset may be any character set registered with IANA
@@ -676,8 +817,10 @@ class Document(ProtoTypeMixin):
         self.convert_uri_to_buffer()
         self.uri = to_datauri(self.mime_type, self.buffer, charset, base64, binary=True)
 
-    def convert_buffer_to_uri(self, charset: str = 'utf-8', base64: bool = False, **kwargs):
-        """ Convert buffer to data uri.
+    def convert_buffer_to_uri(
+        self, charset: str = 'utf-8', base64: bool = False, **kwargs
+    ):
+        """Convert buffer to data uri.
         Internally it first reads into buffer and then converts it to data URI.
 
         :param charset: charset may be any character set registered with IANA
@@ -688,12 +831,16 @@ class Document(ProtoTypeMixin):
         """
 
         if not self.mime_type:
-            raise ValueError(f'{self.mime_type} is unset, can not convert it to data uri')
+            raise ValueError(
+                f'{self.mime_type} is unset, can not convert it to data uri'
+            )
 
         self.uri = to_datauri(self.mime_type, self.buffer, charset, base64, binary=True)
 
-    def convert_text_to_uri(self, charset: str = 'utf-8', base64: bool = False, **kwargs):
-        """ Convert text to data uri.
+    def convert_text_to_uri(
+        self, charset: str = 'utf-8', base64: bool = False, **kwargs
+    ):
+        """Convert text to data uri.
 
         :param charset: charset may be any character set registered with IANA
         :param base64: used to encode arbitrary octet sequences into a form that satisfies the rules of 7bit.
@@ -732,43 +879,24 @@ class Document(ProtoTypeMixin):
         """Copy the content of target :param:doc into current document."""
         self._pb_body.CopyFrom(doc.proto)
 
-    def traverse(self, traversal_path: str, callback_fn: Callable, *args, **kwargs) -> None:
-        """Traverse leaves of the document."""
-        from ..sets import DocumentSet
-        self._traverse_rec(DocumentSet([self]), None, None, traversal_path, callback_fn, *args, **kwargs)
-
-    def _traverse_rec(self, docs: Sequence['Document'], parent_doc: Optional['Document'],
-                      parent_edge_type: Optional[str], traversal_path: str, callback_fn: Callable, *args, **kwargs):
-        if traversal_path:
-            next_edge = traversal_path[0]
-            for doc in docs:
-                if next_edge == 'm':
-                    self._traverse_rec(
-                        doc.matches, doc, 'matches', traversal_path[1:], callback_fn, *args, **kwargs
-                    )
-                elif next_edge == 'c':
-                    self._traverse_rec(
-                        doc.chunks, doc, 'chunks', traversal_path[1:], callback_fn, *args, **kwargs
-                    )
-                else:
-                    raise ValueError(f'"{next_edge}" in "{traversal_path}" is not a valid traversal path')
-        else:
-            for d in docs:
-                callback_fn(d, parent_doc, parent_edge_type, *args, **kwargs)
-
     def __mermaid_str__(self):
         results = []
         from google.protobuf.json_format import MessageToDict
+
         content = MessageToDict(self._pb_body, preserving_proto_field_name=True)
 
         _id = f'{self._mermaid_id[:3]}~Document~'
 
         for idx, c in enumerate(self.chunks):
-            results.append(f'{_id} --> "{idx + 1}/{len(self.chunks)}" {c._mermaid_id[:3]}~Document~: chunks')
+            results.append(
+                f'{_id} --> "{idx + 1}/{len(self.chunks)}" {c._mermaid_id[:3]}~Document~: chunks'
+            )
             results.append(c.__mermaid_str__())
 
         for idx, c in enumerate(self.matches):
-            results.append(f'{_id} ..> "{idx + 1}/{len(self.matches)}" {c._mermaid_id[:3]}~Document~: matches')
+            results.append(
+                f'{_id} ..> "{idx + 1}/{len(self.matches)}" {c._mermaid_id[:3]}~Document~: matches'
+            )
             results.append(c.__mermaid_str__())
         if 'chunks' in content:
             content.pop('chunks')
@@ -794,13 +922,18 @@ class Document(ProtoTypeMixin):
         if img_type == 'jpg':
             img_type = 'img'
 
-        mermaid_str = """
+        mermaid_str = (
+            """
 %%{init: {'theme': 'base', 'themeVariables': { 'primaryColor': '#FFC666'}}}%%
 classDiagram
-        
-        """ + self.__mermaid_str__()
 
-        encoded_str = base64.b64encode(bytes(mermaid_str.strip(), 'utf-8')).decode('utf-8')
+        """
+            + self.__mermaid_str__()
+        )
+
+        encoded_str = base64.b64encode(bytes(mermaid_str.strip(), 'utf-8')).decode(
+            'utf-8'
+        )
 
         return f'https://mermaid.ink/{img_type}/{encoded_str}'
 
@@ -808,8 +941,7 @@ classDiagram
         """Displays the object in IPython as a side effect"""
         self.plot(inline_display=True)
 
-    def plot(self, output: str = None,
-             inline_display: bool = False) -> None:
+    def plot(self, output: str = None, inline_display: bool = False) -> None:
         """
         Visualize the Document recursively.
 
@@ -837,6 +969,7 @@ classDiagram
             download_mermaid_url(url, output)
         elif not showed:
             from jina.logging import default_logger
+
             default_logger.info(f'Document visualization: {url}')
 
     @property
