@@ -1,4 +1,4 @@
-from typing import Dict, Sequence, List, Optional, Any
+from typing import Dict, Sequence, List, Optional, Any, Tuple
 
 from . import Document, DocumentSourceType, typename, DocumentContentType
 from ...excepts import BadDocType
@@ -17,10 +17,14 @@ class MultimodalDocument(Document):
         - It assumes that every :class:`MultimodalDocument` have at least two chunks.
     """
 
-    def __init__(self, document: Optional[DocumentSourceType] = None,
-                 chunks: Sequence[Document] = None,
-                 modality_content_map: Dict[str, DocumentContentType] = None,
-                 copy: bool = False, **kwargs):
+    def __init__(
+        self,
+        document: Optional[DocumentSourceType] = None,
+        chunks: Sequence[Document] = None,
+        modality_content_map: Dict[str, DocumentContentType] = None,
+        copy: bool = False,
+        **kwargs,
+    ):
         """
 
         :param document: the document to construct from. If ``bytes`` is given
@@ -44,10 +48,17 @@ class MultimodalDocument(Document):
         super().__init__(document=document, copy=copy, **kwargs)
         if chunks or modality_content_map:
             if chunks:
-                granularities = [chunk.granularity for chunk in chunks]
-                if len(set(granularities)) != 1:
+                g = {c.granularity for c in chunks}
+                if len(g) != 1:
                     raise BadDocType('Each chunk should have the same granularity.')
                 self.chunks.extend(chunks)
+
+                # in case chunks have granularity defined, override
+                gv = list(g)[0]
+                if gv != 0:
+                    for c in self.chunks:
+                        c.granularity = gv
+
             elif modality_content_map:
                 self.modality_content_map = modality_content_map
             self._handle_chunk_level_attributes()
@@ -56,8 +67,8 @@ class MultimodalDocument(Document):
     def is_valid(self) -> bool:
         """A valid :class:`MultimodalDocument` should meet the following requirements:
 
-            - Document should consist at least 2 chunks.
-            - Length of modality is not identical to length of chunks.
+        - Document should consist at least 2 chunks.
+        - Length of modality is not identical to length of chunks.
         """
         modalities = set([chunk.modality for chunk in self.chunks])
         return 2 <= len(self.chunks) == len(modalities)
@@ -94,11 +105,14 @@ class MultimodalDocument(Document):
         result = {}
         for chunk in self.chunks:
             modality = chunk.modality
-            result[modality] = chunk.embedding if chunk.embedding is not None else chunk.content
+            result[modality] = (
+                chunk.embedding if chunk.embedding is not None else chunk.content
+            )
         return result
 
     @modality_content_map.setter
     def modality_content_map(self, value: Dict[str, Any]):
+        """Set the mapping of modality and content."""
         for modality, content in value.items():
             with Document() as chunk:
                 chunk.modality = modality
@@ -123,3 +137,9 @@ class MultimodalDocument(Document):
         :return: List of modalities extracted from chunks of the document.
         """
         return list(self.modality_content_map.keys())
+
+    def update_content_hash(
+        self, exclude_fields: Tuple[str] = ('id', 'matches', 'content_hash')
+    ) -> None:
+        """Update content hash of the document by including ``chunks`` when computing the hash"""
+        super().update_content_hash(exclude_fields)
